# PyQt-ext
Collection of PyQt/PySide widgets/tools.

- [PyQtAbstractTreeItem](https://github.com/marcel-goldschen-ohm/PyQt-ext/docs/PyQtAbstractTreeItem.md)
- [PyQtAbstractTreeModel](https://github.com/marcel-goldschen-ohm/PyQt-ext/docs/PyQtAbstractTreeModel.md)
- [PyQtAbstractTreeView](https://github.com/marcel-goldschen-ohm/PyQt-ext/docs/PyQtAbstractTreeView.md)
- [PyQtColorButton](https://github.com/marcel-goldschen-ohm/PyQt-ext/docs/PyQtColorButton.md)
- [PyQtKeyValueTreeItem](https://github.com/marcel-goldschen-ohm/PyQt-ext/docs/PyQtKeyValueTreeItem.md)
- [PyQtKeyValueTreeModel](https://github.com/marcel-goldschen-ohm/PyQt-ext/docs/PyQtKeyValueTreeModel.md)
- [PyQtKeyValueTreeView](https://github.com/marcel-goldschen-ohm/PyQt-ext/docs/PyQtKeyValueTreeView.md)
- [PyQtMultiValueSpinBox](https://github.com/marcel-goldschen-ohm/PyQt-ext/docs/PyQtMultiValueSpinBox.md)
- [PyQtXYDataStyle](https://github.com/marcel-goldschen-ohm/PyQt-ext/docs/PyQtXYDataStyle.md)

# Install
Should work with PySide6, PyQt6, or PyQt5.
```shell
pip install PySide6 pyqt-ext
```
